@@ -27,7 +27,7 @@ from typing import Optional
 
 from com.dtmilano.android.adb.dumpsys import Dumpsys
 
-__version__ = '21.11.0'
+__version__ = '21.12.0'
 
 import sys
 import warnings
@@ -226,6 +226,9 @@ class AdbClient:
         self.display = {}
         ''' The map containing the device's physical display properties: width, height and density '''
 
+        self.screenshot_number = 1
+        ''' The screenshot number count '''
+
         self.isTransportSet = False
         if settransport and serialno is not None:
             self.__setTransport(timeout=timeout)
@@ -932,6 +935,7 @@ class AdbClient:
 
         if PROFILE:
             profileEnd()
+        self.screenshot_number += 1
         return image
 
     def imageToData(self, image, output_type=None):
@@ -1421,6 +1425,7 @@ class AdbClient:
 
     def substituteDeviceTemplate(self, template):
         serialno = self.serialno.replace('.', '_').replace(':', '-')
+        pid = os.getpid()
         window_name = self.getFocusedWindowName() or 'no_name'
         focusedWindowName = window_name.replace('/', '-').replace('.', '_')
         timestamp = datetime.datetime.now().isoformat()
@@ -1428,6 +1433,8 @@ class AdbClient:
         if osName.startswith('Windows'):  # ':' not supported in filenames
             timestamp.replace(':', '_')
         _map = {
+            'screenshot_number': f'{self.screenshot_number:04d}',
+            'pid': pid,
             'serialno': serialno,
             'focusedwindowname': focusedWindowName,
             'timestamp': timestamp
